@@ -3,7 +3,10 @@
 #'These functions provide information about the stable distribution
 #'with the location, the dispersion, the skewness and the tail thickness
 #'respectively modelled by the parameters \code{loc}, \code{disp},
-#'\code{skew} and  \code{tail}.
+#'\code{skew} and  \code{tail}. These differ from those of 'stabledist' (i.e., Nolan's 0-parameterization and 
+#'1-parameterization as detailed in Nolan (2020)). See the README for how to make equivalent calls
+#'to those of 'stabledist' (i.e., Nolan's 0-parameterization and 
+#'1-parameterization as detailed in Nolan (2020)). 
 #'
 #'\code{dstable}, \code{pstable}, \code{qstable} and \code{hstable}
 #'compute the density, the distribution, the quantile and the hazard functions
@@ -54,16 +57,20 @@
 #'\code{npt} -- are only available when using \code{dstable}.
 #'The other functions are all based on Romberg's algorithm.
 #'
-#' [Swihart 2022 update:] See the README for how to make equivalent calls
+#' [Swihart 2022 update:] 
+#' 
+#' 
+#' See the README for how to make equivalent calls
 #' to those of 'stabledist' (i.e., Nolan's 0-parameterization and 1-parameterization 
 #' as detailed in Nolan (2020)). 
 #' See github for Lambert and Lindsey 1999 JRSS-C journal article, 
 #' which details the parameterization of the Buck (1995) stable distribution which allowed
-#' a Fourier inversion to arrive at a form of the $g_d$ function as detailed in Nolan (2020),
+#' a Fourier inversion to arrive at a form similar to but not exactly the $g_d$ 
+#' function as detailed in Nolan (2020),
 #' Abdul-Hamid and Nolan (1998) and Nolan (1997).  
 #' The Nolan (2020) reference is a textbook that provides
 #' an accessible and comprehensive summary of stable distributions in the 25 years or so
-#' since this core of this R package was made.  
+#' since the core of this R package was made and put on CRAN.  
 #' The Buck (1995) parameterization most closely resembles the Zolotarev B parameterization
 #' outlined in Definition 3.6 on page 93 of Nolan (2020) -- except that Buck (1995) did
 #' not allow the scale parameter to multiply with the location parameter.  
@@ -71,6 +78,19 @@
 #' the location parameter being multiplied by the scale parameter whereas in converting the Lindsey and Lambert (1999)
 #' to Nolan 1-parameterization the location parameter stays the same.  
 #'
+#' To be clear, \code{stable::dstable} and \code{stable::pstable} are evaluated 
+#' by numerically integrating the inverse Fourier transform.  The code works 
+#' reasonably for small and moderate values of x, but will have numerical issues 
+#' in some cases of large x (such as values from \code{stable::pstable} being greater than 
+#' 1 or or not being monotonic).  The arguments \code{npt}, \code{up}, 
+#' \code{integration}, and \code{eps} can be adjusted 
+#' to improve accuracy at the cost of speed, but will still have limitations.
+#' Functions that better handle these problems are available in other packages
+#' (such as \code{stabledist} and \code{stable}) that use an alternative method
+#' (as detailed in Nolan 1997)  
+#' distinct from directly numerically integrating the Fourier inverse transform. 
+#' See last example in the README.
+#' 
 #' @param x,q vector of quantiles.
 #' @param p vector of probabilites.
 #' @param n number of observations.
@@ -80,6 +100,8 @@
 #' @param tail vector of parameters (in [0,2]) related to the tail thickness.
 #' @param eps scalar giving the required precision in computation.
 #' @param npt,up,integration As detailed herein -- only available when using \code{dstable}.
+#' @param object the object of the default generic
+#' @param ... the usual R definition
 #'
 #' @references Lambert, P. and Lindsey, J.K. (1999) Analysing financial returns using
 #' regression models based on non-symmetric stable distributions. Applied
@@ -92,7 +114,8 @@
 #' @references Abdul-Hamid, Husein, and John P. Nolan. "Multivariate stable densities as functions of one dimensional projections." Journal of multivariate analysis 67.1 (1998): 80-89.
 #' 
 #' @seealso \code{\link[stable]{stablereg}} to fit generalized nonlinear regression models
-#' for the stable distribution parameters.
+#' for the stable distribution parameters. 
+#' R packages \code{stabledist} and \code{libstableR} provide [dpqr] functions.
 #'
 #' @author Philippe Lambert (Catholic University of Louvain, Belgium, \email{phlambert@stat.ucl.ac.be})
 #' @author Jim Lindsey
@@ -398,7 +421,7 @@ tail_h <- function(x) 2/(1+exp(-x))
 #' explanatory variables.
 #'
 #'
-#' @aliases stablereg fitted.stable df.residual.stable deviance.stable
+#' @aliases stablereg df.residual.stable deviance.stable
 #' aic.stable
 #' @param y The response vector or a \code{repeated} data object. If the
 #' \code{repeated} data object contains more than one response variable, give
@@ -1255,17 +1278,34 @@ z1}
 ###########################################################################
 # Stable class functions
 #
-fitted.stable <- function(z) z$loc
 
-df.residual.stable <- function(z) z$df
+#
+# This function produces the stable density computed at y.
+# Note that it is obtained by integrating a function from 0 to Infinity.
+# This integral is approximated by the finite integral from 0 to UP
+# using the Simpson's method with npt points or Romberg's integration
+#' @describeIn stable support functions
+#' @export
+fitted.stable <- function(object, ...) object$loc
+#' @export
+df.residual.stable <- function(object, ...) object$df
+
+# foo <- function(object, ...) UseMethod("foo")
+# foo.default <- function(object, ...) base::foo(object)
+# 
 
 aic <- function (object, ...)
 	UseMethod("aic")
-aic.stable <- function(z) z$aic
 
-deviance.stable <- function(z) 2*z$llik
+#' @export
+aic.stable <- function(object, ...) object$aic
 
-print.stable <- function(z,digits=max(4,.Options$digits-3),correlation=TRUE) {
+#' @export
+deviance.stable <- function(object, ...) 2*object$llik
+
+#' @export
+print.stable <- function(x,digits=max(4,.Options$digits-3),correlation=TRUE, ...) {
+  z <- x
 np <- z$npar.opt
 if(!z$oloc)nploc <- 0
 if(!z$odisp)npdisp <- 0
